@@ -29,8 +29,8 @@ class Modify(
         Delete,
         SoftDelete
 ):
-    def __init__(self, **options):
-        self.modify(options)
+    def __init__(self, **initial_datum):
+        self.modify(initial_datum)
 
     def modify(self, datum: dict, skipped_keys: List[str] = []):
         self.check_not_soft_deleted()
@@ -70,7 +70,6 @@ class Modify(
                     datum[key]
                 )
                 setattr(self, key, value)
-
         return self
 
     @staticmethod
